==> rktSNS_1.070202.tgz: rktSNS/works/sqls/mailtpl.sql <==
BEGIN TRANSACTION;

-- -------------------------------------------------------- 
--  テーブルデータ sns_sys_mailtpl 
-- --------------------------------------------------------
INSERT INTO sns_sys_mailtpl VALUES('1','2006-07-22 05:35:11','inquire','お問合せメールを受理いたしました','admin@example.com','rktSNS','◆　お問合せありがとうございました。　◆

以下の内容でお問合せのメールを受理いたしました。

====================================================
・お名前　　　　　：　{$user_name} 様
・メールアドレス　：　{$email}

・ご質問の内容　　：
{$comment}


{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('2','2006-07-22 05:35:11','invitation','招待状が届いています','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
このたびは、「{$site_name}」をご利用いただいている、
{$user_name}さんからの招待メールを配信いたしました。

-----{$user_name}さんからのメッセージ-----
{$comment}
-------------------------------------------------

下記URLを開き是非、ご参加ください。
{$url}

確定ページが正しく表示されない場合
　セキュリティのため、URLが長く設定されています。
　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
　その際はブラウザのアドレス欄へ直接コピーなどをして入力してください。

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('3','2006-08-21 12:09:55','reissue','パスワードを忘れた方','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name}さん
[パスワード]:{$password}


{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('4','2006-07-22 05:35:11','registry','rktSNS入会確認','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

このたびは、「{$site_name}」へご会員登録頂きありがとうございます。
下記URLページを開き、登録内容を確定して下さい。
登録内容が確定すると「{$site_name}」のサービスがご利用頂けます。

{$url}


登録内容の確定が長期間保留された場合、ご登録内容を全て破棄いたします。
その際は、改めてご登録をやり直してください。

確定ページが正しく表示されない場合
　セキュリティのため、URLが長く設定されています。
　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
　その際はブラウザのアドレス欄へ直接コピーなどをして入力してください。

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('5','2006-07-22 05:35:11','friendsOK','お友達承認完了のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんは、{$user_name} さんを
お友達に登録されることを承認されました。

{$friend} さんのプロフィールを見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('6','2006-07-22 05:35:11','friendsNG','お友達承認完了のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんは、{$user_name} さんを
お友達に登録されることを見送る事になりました。

{$friend} さんのプロフィールを見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('7','2006-07-22 05:35:11','entryOK','コミュニティ参加のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$community}へ{$user_name} さんの参加が承認されました。


{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('8','2006-07-22 05:35:11','entryNG','コミュニティ参加のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$community}へ{$user_name} さんの参加を見送る事になりました。

{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('9','2006-07-22 05:35:11','change','管理人交代のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんは、{$user_name} さんからの
{$community}の管理人交代を{$result}されました。


----------------------{$community}----------------------
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('10','2006-07-22 05:35:11','change_request','管理人交代の願い','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name} さんに {$friend} さんからの
{$community}の管理人交代のお願いがあります。


{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

認証処理を行うには以下のURLをクリックして認証手続きを
行ってください。
{$url2}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('11','2006-07-22 05:35:11','names_delete','コミュニティ退会のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$community}から{$user_name} さんが退会されました。

{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('12','2006-07-22 05:35:11','intro','紹介文のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんから、{$user_name} さんへの
紹介文を掲載しました。

{$user_name} さんの紹介文を見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('13','2006-07-22 05:35:11','relation','お友達登録のお願い','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんから、{$user_name} さんへ
お友達登録の申請がありました。

-----{$friend}さんからのメッセージ-----
{$comment}

-------------------------------------------------

お友達に追加するには以下のページから承認や拒否の
手続きを行ってください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('14','2006-07-22 05:35:11','message','メッセージが届いています。','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんから、{$user_name} さんへ
メッセージがあります。

メッセージの内容を確認するには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('15','2006-07-22 05:35:11','topic','イベントメッセージが届いています','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

イベントの企画者 {$friend} さんからのお知らせです。

グループ名：{$community}
イベント名：{$topic}


メッセージを確認するには以下のURLをクリックしてください。
{$url2}


{$topic} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('16','2006-07-22 05:35:11','footprint','キリ番のおしらせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name} さんへのページアクセスがなんと！
{$footprint}アクセスを達成いたしました。

栄えある{$footprint}アクセス目の訪問者は
{$friend} さんです。


{$friend} さんのプロフィールを見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('17','2006-07-22 05:35:11','daily','rktSNSニュース','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

■□□□□□□□□□□□□□□ {$now} □□□■

{$user_name} さんに関連したニュースを配信いたします。

■□□□□□□□□□□□□□□□□□□□□□□□■


{empty $fdiarys}
==================================================
　　　　　お友達の最新日記
{foreach $fdiarys}
{$_row.modify} … {$_row.subject}({$_row.nickname}さん)

　　　　URL … {$http_action}friend/diary/entry/{$_row.ref_friend}/?id={$_row.ref_entry}

{/foreach}


{/empty}
{empty $adiarys}
==================================================
　　　　　更新アラート設定日記
{foreach $adiarys}
{$_row.modify} … {$_row.subject} ({$_row.ct})

　　　　URL … {$http_action}friend/diary/entry/{$_row.ref_friend}/?id={$_row.ref_entry}

{/foreach}


{/empty}
{empty $topics}
==================================================
　　　　　コミュニティ掲示板
{foreach $topics}
{$_row.modify} … {$_row.topic}({$_row.ct}) ({$_row.community})

　　　　URL … {$http_action}community/bbs/browse/{$_row.ref_community}/{$_row.ref_topic}/

{/foreach}


{/empty}
{empty $comments}
==================================================
　　　　　日記書へのコメント
{foreach $comments}

{$_row.modify} … {$_row.subject} ({$_row.ct})

　　　　URL … {$http_action}private/diary/entry/?id={$_row.ref_entry}#comment

{/foreach}


{/empty}
{empty $news}
==================================================
　　　　　お伝えできる情報はありませんでした。

{/empty}
{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('18','2006-07-22 05:35:11','auto_invite','新規登録ご招待','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
招待メールを送信させて頂きました。

下記URLを開き是非、ご参加ください。
{$url}

確定ページが正しく表示されない場合
　セキュリティのため、URLが長く設定されています。
　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
　その際はブラウザのアドレス欄へ直接コピーなどをして入力してください。

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('19','2006-08-21 18:31:24','re_inquire','問合せ返信','admin@example.com','rktSNS','{$body}

{$footer}');

INSERT INTO sns_sys_mailtpl VALUES('20','2006-09-25 12:45:06','mailing','メール配信','admin@example.com','rktSNS','こんにちは、{$user_name} さん。

{$body}

{$footer}');

INSERT INTO sns_sys_mailtpl VALUES('21','2006-07-22 05:35:11','schedule','スケジュールのお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name} さんへのスケジュールのお知らせをいたします。

==================================================
　　　　　本日のご予定

{foreach $schedules}
{$_row.start_date}{$_row.start_hour}時{$_row.start_minute}分 … {$_row.schedule}

　　　　URL … {$url}id={$_row.id}

{/foreach}

{$footer}');

COMMIT;

==> rktSNS_1.070204.tgz: rktSNS/works/sqls/mailtpl.sql <==
BEGIN TRANSACTION;

-- -------------------------------------------------------- 
--  テーブルデータ sns_sys_mailtpl 
-- --------------------------------------------------------
INSERT INTO sns_sys_mailtpl VALUES('1','2006-07-22 05:35:11','inquire','お問合せメールを受理いたしました','admin@example.com','rktSNS','◆　お問合せありがとうございました。　◆

以下の内容でお問合せのメールを受理いたしました。

====================================================
・お名前　　　　　：　{$user_name} 様
・メールアドレス　：　{$email}

・ご質問の内容　　：
{$comment}


{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('2','2006-07-22 05:35:11','invitation','招待状が届いています','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
このたびは、「{$site_name}」をご利用いただいている、
{$user_name}さんからの招待メールを配信いたしました。

-----{$user_name}さんからのメッセージ-----
{$comment}
-------------------------------------------------

下記URLを開き是非、ご参加ください。
{$url}

確定ページが正しく表示されない場合
　セキュリティのため、URLが長く設定されています。
　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
　その際はブラウザのアドレス欄へ直接コピーなどをして入力してください。

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('3','2006-08-21 12:09:55','reissue','パスワードを忘れた方','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name}さん
[パスワード]:{$password}


{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('4','2006-07-22 05:35:11','registry','rktSNS入会確認','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

このたびは、「{$site_name}」へご会員登録頂きありがとうございます。
下記URLページを開き、登録内容を確定して下さい。
登録内容が確定すると「{$site_name}」のサービスがご利用頂けます。

{$url}


登録内容の確定が長期間保留された場合、ご登録内容を全て破棄いたします。
その際は、改めてご登録をやり直してください。

確定ページが正しく表示されない場合
　セキュリティのため、URLが長く設定されています。
　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
　その際はブラウザのアドレス欄へ直接コピーなどをして入力してください。

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('5','2006-07-22 05:35:11','friendsOK','お友達承認完了のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんは、{$user_name} さんを
お友達に登録されることを承認されました。

{$friend} さんのプロフィールを見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('6','2006-07-22 05:35:11','friendsNG','お友達承認完了のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんは、{$user_name} さんを
お友達に登録されることを見送る事になりました。

{$friend} さんのプロフィールを見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('7','2006-07-22 05:35:11','entryOK','コミュニティ参加のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$community}へ{$user_name} さんの参加が承認されました。


{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('8','2006-07-22 05:35:11','entryNG','コミュニティ参加のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$community}へ{$user_name} さんの参加を見送る事になりました。

{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('9','2006-07-22 05:35:11','change','管理人交代のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんは、{$user_name} さんからの
{$community}の管理人交代を{$result}されました。


----------------------{$community}----------------------
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('10','2006-07-22 05:35:11','change_request','管理人交代の願い','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name} さんに {$friend} さんからの
{$community}の管理人交代のお願いがあります。


{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

認証処理を行うには以下のURLをクリックして認証手続きを
行ってください。
{$url2}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('11','2006-07-22 05:35:11','names_delete','コミュニティ退会のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$community}から{$user_name} さんが退会されました。

{$community} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('12','2006-07-22 05:35:11','intro','紹介文のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんから、{$user_name} さんへの
紹介文を掲載しました。

{$user_name} さんの紹介文を見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('13','2006-07-22 05:35:11','relation','お友達登録のお願い','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんから、{$user_name} さんへ
お友達登録の申請がありました。

-----{$friend}さんからのメッセージ-----
{$comment}

-------------------------------------------------

お友達に追加するには以下のページから承認や拒否の
手続きを行ってください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('14','2006-07-22 05:35:11','message','メッセージが届いています。','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$friend} さんから、{$user_name} さんへ
メッセージがあります。

メッセージの内容を確認するには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('15','2006-07-22 05:35:11','topic','イベントメッセージが届いています','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

イベントの企画者 {$friend} さんからのお知らせです。

グループ名：{$community}
イベント名：{$topic}


メッセージを確認するには以下のURLをクリックしてください。
{$url2}


{$topic} の情報を見るには以下のURLをクリックしてください。
{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('16','2006-07-22 05:35:11','footprint','キリ番のおしらせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name} さんへのページアクセスがなんと！
{$footprint}アクセスを達成いたしました。

栄えある{$footprint}アクセス目の訪問者は
{$friend} さんです。


{$friend} さんのプロフィールを見るには以下の
URLをクリックしてください。

{$url}

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('17','2006-07-22 05:35:11','daily','rktSNSニュース','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

■□□□□□□□□□□□□□□ {$now} □□□■

{$user_name} さんに関連したニュースを配信いたします。

■□□□□□□□□□□□□□□□□□□□□□□□■


{empty $fdiarys}
==================================================
　　　　　お友達の最新日記
{foreach $fdiarys}
{$_row.modify} … {$_row.subject}({$_row.nickname}さん)

　　　　URL … {$http_action}friend/diary/entry/{$_row.ref_friend}/{$uri_separator}id={$_row.ref_entry}

{/foreach}


{/empty}
{empty $topics}
==================================================
　　　　　コミュニティ掲示板
{foreach $topics}
{$_row.modify} … {$_row.topic}({$_row.ct}) ({$_row.community})

　　　　URL … {$http_action}community/bbs/browse/{$_row.ref_community}/{$_row.ref_topic}/

{/foreach}


{/empty}
{empty $comments}
==================================================
　　　　　日記書へのコメント
{foreach $comments}

{$_row.modify} … {$_row.subject} ({$_row.ct})

　　　　URL … {$http_action}private/diary/entry/{$uri_separator}id={$_row.ref_entry}#comment

{/foreach}


{/empty}
{empty $news}
==================================================
　　　　　お伝えできる情報はありませんでした。

{/empty}
{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('18','2006-07-22 05:35:11','auto_invite','新規登録ご招待','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
招待メールを送信させて頂きました。

下記URLを開き是非、ご参加ください。
{$url}

確定ページが正しく表示されない場合
　セキュリティのため、URLが長く設定されています。
　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
　その際はブラウザのアドレス欄へ直接コピーなどをして入力してください。

{$footer}');
INSERT INTO sns_sys_mailtpl VALUES('19','2006-08-21 18:31:24','re_inquire','問合せ返信','admin@example.com','rktSNS','{$body}

{$footer}');

INSERT INTO sns_sys_mailtpl VALUES('20','2006-09-25 12:45:06','mailing','メール配信','admin@example.com','rktSNS','こんにちは、{$user_name} さん。

{$body}

{$footer}');

INSERT INTO sns_sys_mailtpl VALUES('21','2006-07-22 05:35:11','schedule','スケジュールのお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。

{$user_name} さんへのスケジュールのお知らせをいたします。

==================================================
　　　　　本日のご予定

{foreach $schedules}
{$_row.start_date}{$_row.start_hour}時{$_row.start_minute}分 … {$_row.schedule}

　　　　URL … {$url}id={$_row.id}

{/foreach}

{$footer}');

COMMIT;
